| /freebsd-13.1/contrib/llvm-project/clang/lib/Headers/ |
| H A D | __clang_cuda_intrinsics.h | 25 inline __device__ int __FnName(int __val, __Type __offset, \ 27 return __IntIntrinsic(__val, __offset, \ 30 inline __device__ float __FnName(float __val, __Type __offset, \ 32 return __FloatIntrinsic(__val, __offset, \ 35 inline __device__ unsigned int __FnName(unsigned int __val, __Type __offset, \ 38 ::__FnName(static_cast<int>(__val), __offset, __width)); \ 40 inline __device__ long long __FnName(long long __val, __Type __offset, \ 49 __tmp.__a = ::__FnName(__tmp.__a, __offset, __width); \ 50 __tmp.__b = ::__FnName(__tmp.__b, __offset, __width); \ 55 inline __device__ long __FnName(long __val, __Type __offset, \ [all …]
|
| H A D | vecintrin.h | 863 (const char *)__ptr + __offset[__index]); in vec_gather_element() 873 (const char *)__ptr + __offset[__index]); in vec_gather_element() 883 (const char *)__ptr + __offset[__index]); in vec_gather_element() 893 (const char *)__ptr + __offset[__index]); in vec_gather_element() 903 (const char *)__ptr + __offset[__index]); in vec_gather_element() 913 (const char *)__ptr + __offset[__index]); in vec_gather_element() 924 (const char *)__ptr + __offset[__index]); in vec_gather_element() 935 (const char *)__ptr + __offset[__index]); in vec_gather_element() 1083 vec_xl(long __offset, const float *__ptr) { in vec_xl() argument 1092 vec_xl(long __offset, const double *__ptr) { in vec_xl() argument [all …]
|
| H A D | altivec.h | 17563 return *(unaligned_vec_uchar*)(__ptr + __offset); in vec_xl() 17703 return vec_xl(__offset, __ptr); in vec_xl_be() 17708 return vec_xl(__offset, __ptr); in vec_xl_be() 17913 *(__ptr + __offset) = (signed char)__vec[0]; in vec_xst_trunc() 17919 *(__ptr + __offset) = (unsigned char)__vec[0]; in vec_xst_trunc() 17925 *(__ptr + __offset) = (signed short)__vec[0]; in vec_xst_trunc() 17931 *(__ptr + __offset) = (unsigned short)__vec[0]; in vec_xst_trunc() 17937 *(__ptr + __offset) = (signed int)__vec[0]; in vec_xst_trunc() 17943 *(__ptr + __offset) = (unsigned int)__vec[0]; in vec_xst_trunc() 18043 vec_xst(__vec, __offset, __ptr); in vec_xst_be() [all …]
|
| /freebsd-13.1/contrib/llvm-project/compiler-rt/lib/asan/ |
| H A D | asan_interceptors_memintrinsics.h | 53 uptr __offset = (uptr)(offset); \ in DECLARE_REAL() 56 if (__offset > __offset + __size) { \ in DECLARE_REAL() 58 ReportStringFunctionSizeOverflow(__offset, __size, &stack); \ in DECLARE_REAL() 60 if (!QuickCheckForUnpoisonedRegion(__offset, __size) && \ in DECLARE_REAL() 61 (__bad = __asan_region_is_poisoned(__offset, __size))) { \ in DECLARE_REAL()
|
| /freebsd-13.1/contrib/llvm-project/libcxx/include/ |
| H A D | span | 324 subspan(size_type __offset, size_type __count = dynamic_extent) const noexcept 326 _LIBCPP_ASSERT(__offset <= size(), "Offset out of range in span::subspan(offset, count)"); 329 return {data() + __offset, size() - __offset}; 330 …_LIBCPP_ASSERT(__count <= size() - __offset, "Offset + count out of range in span::subspan(offset,… 331 return {data() + __offset, __count}; 486 subspan(size_type __offset, size_type __count = dynamic_extent) const noexcept 488 _LIBCPP_ASSERT(__offset <= size(), "Offset out of range in span::subspan(offset, count)"); 491 return {data() + __offset, size() - __offset}; 492 …_LIBCPP_ASSERT(__count <= size() - __offset, "Offset + count out of range in span::subspan(offset,… 493 return {data() + __offset, __count};
|
| H A D | regex | 6045 int __offset = (__flags & regex_constants::match_prev_avail) ? 1 : 0; 6046 basic_string<_CharT> __s(_VSTD::prev(__first, __offset), __last); 6048 bool __r = __e.__search(__s.data() + __offset, __s.data() + __s.size(), __mc, __flags);
|
| /freebsd-13.1/include/ |
| H A D | nl_types.h | 75 int32_t __offset; member
|
| /freebsd-13.1/contrib/llvm-project/compiler-rt/lib/msan/ |
| H A D | msan_interceptors.cpp | 104 sptr __offset = __msan_test_shadow(x, n); \ 106 if (__offset >= 0 && __msan::flags()->report_umrs) { \ 109 ReportUMRInsideAddressRange(__func__, x, n, __offset); \ 111 pc, bp, __msan_get_origin((const char *)x + __offset)); \
|
| /freebsd-13.1/lib/libc/nls/ |
| H A D | msgcat.c | 320 msg_hdr[i].__offset)); in catgets()
|
| /freebsd-13.1/usr.bin/gencat/ |
| H A D | gencat.c | 560 msg_hdr->__offset = htonl(msg_offset);
|